/*
 * kdfwidget.h
 *
 * Copyright (c) 1998 Michael Kropfberger <mkropfbe@edu.uni-klu.ac.at>
 *
 * Requires the Qt widget libraries, available at no cost at
 * http://www.troll.no/
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */


#ifndef __KDFWIDGET_H__
#define __KDFWIDGET_H__


#include <qlcdnum.h> 
#include <qlabel.h> 
#include <qbttngrp.h>
#include <qpushbt.h>
#include <qradiobt.h>
#include <qlist.h>
#include <qlined.h>
#include <qlayout.h>
#include <qscrbar.h>
#include <qarray.h>
 
#include <kapp.h>
#include <kslider.h>
#include <kcontrol.h>
#include <ktablistbox.h>

// defines the os-type
#include <qglobal.h>

#include "disks.h"

#define DF_COMMAND    "df"
// be pessimistic: df -T only works under linux !??
#if defined(_OS_LINUX_)
#define DF_ARGS       "-kT"
#define NO_FS_TYPE    false
#else
#define DF_ARGS       "-k"
#define NO_FS_TYPE    true
#endif		

#ifdef _OS_SOLARIS_
#define CACHEFSTAB "/etc/cachefstab"
#define FSTAB "/etc/vfstab"
#else
#define FSTAB "/etc/fstab"
#endif

#define MOUNT_COMMAND "mount"
#define UMOUNT_COMMAND "umount"

/**************************************************************/

#if defined(DEFAULT_TEMPLATECLASS)
typedef QListT<DiskEntry>		DiskListBase;
typedef QListIteratorT<DiskEntry>	DiskListIterator;
#else
typedef Q_DECLARE(QListM,KDFEntry)	DiskListBase;
typedef Q_DECLARE(QListIteratorM,KDFEntry) DiskListIterator;
#endif



class DiskList : public DiskListBase
{
public:
    DiskList( bool deepCopies=TRUE ) { dc = deepCopies; }
   ~DiskList()			{ clear(); }

private:
     int compareItems( GCI s1, GCI s2 )  {
	int ret;
	ret = strcmp (static_cast<DiskEntry*>(s1)->deviceName(),
		      static_cast<DiskEntry*>(s2)->deviceName() );
	if (0 == ret)
	   ret = strcmp (static_cast<DiskEntry*>(s1)->mountPoint(),
			 static_cast<DiskEntry*>(s2)->mountPoint());
	return ret;
     };
   bool  dc;
};

/************************************************************/

class KDFWidget : public KConfigWidget
{
  Q_OBJECT
public:
  KDFWidget( QWidget *parent=0, const char *name=0, bool init=FALSE );
   ~KDFWidget();

public slots:
  void loadSettings();
  void applySettings();
  void readFSTAB();
  void readDF();
  
private slots:
   void receivedSysStdErrOut(KProcess *, char *data, int len);
   void receivedDFStdErrOut(KProcess *, char *data, int len);
   void dfDone();
   void sysCallDone();
   void headerClicked(int column);
   void toggleColumnVisibility(int column);
   void toggleColumnVisibility(int,int column)
         { toggleColumnVisibility(column); }; //overloaded
   void popupMenu(int row,int column);
   void settingsBtnClicked();
   void defaultsBtnClicked();
   void setUpdateFreq(int freq);
   void invokeHTMLHelp() { kapp->invokeHTMLHelp("kcontrol/kdf/index.html",""); };

protected:
  void paintEvent( QPaintEvent * );       
  void resizeEvent( QResizeEvent * );       
  void  timerEvent( QTimerEvent * );
  void closeEvent( QCloseEvent * );

private:
  void sysCall(QString command);


  void replaceDeviceEntry(DiskEntry *disk);
  void updatePixmaps();

  KConfig           *config;

  QStrList          tabHeaders;
  QArray<int>       tabWidths;

  KTabListBox      *tabList;
  DiskList          diskList;
  KProcess         *dfProc;
  KProcess         *sysProc;
  QString           dfStringErrOut;
  QString           sysStringErrOut;
  bool              readingDFStdErrOut;
  bool              readingSysStdErrOut;
  int               updateFreq;

  KTabListBox      *confTabList;
  QGroupBox        *settingsBox;
  QLabel           *freqLabel
                  ,*fileMgrLabel;
  QScrollBar       *freqScroll;
  QLCDNumber       *freqLCD;
  QPushButton      *settingsBtn
                  ,*defaultsBtn
                  ,*helpBtn;
  QLineEdit        *fileMgrEdit;
  bool             showSettings;
  bool             isTopLevel;
  bool             popupIfFull;
  
 
};


#endif
